@@ -683,8 +683,10 @@ runexttosim:
 	EFVisitDevs(simmergeVisit, PTR2CD(NULL));
 	TxPrintf("Devices merged: %d\n", esDevsMerged);
 	esFMIndex = 0;
+	free_magic1_t mm1 = freeMagic1_init();
 	for (p = devMergeList; p != NULL; p = p->next)
-	    freeMagic((char *)p);
+	    freeMagic1(&mm1, (char *)p);
+	freeMagic1_end(&mm1);
 	devMergeList = NULL;
     }
 
