@@ -2201,11 +2201,13 @@ esMakePorts(
     }
 
     /* Free table data */
+    free_magic1_t mm1 = freeMagic1_init();
     while (flagtop != NULL)
     {
-	freeMagic((char *)flagtop);
+	freeMagic1(&mm1, (char *)flagtop);
 	flagtop = flagtop->fdr_next;
     }
+    freeMagic1_end(&mm1);
     HashKill(&flagHashTable);
     return 0;
 }
@@ -2337,8 +2339,10 @@ esHierVisit(
 	    EFHierVisitDevs(hcf, spcdevHierMergeVisit, (ClientData)NULL);
 	    TxPrintf("Devs merged: %d\n", esSpiceDevsMerged);
 	    esFMIndex = 0;
+	    free_magic1_t mm1 = freeMagic1_init();
 	    for (p = devMergeList; p != NULL; p = p->next)
-		freeMagic((char *)p);
+		freeMagic1(&mm1, (char *)p);
+	    freeMagic1_end(&mm1);
 	    devMergeList = NULL;
 	}
 	else if (esDistrJunct)
