@@ -416,12 +416,13 @@ efHierDevKilled(hc, dev, prefix)
  * Visit all the devs in the circuit.
  * For each dev in the circuit, call the user-supplied procedure
  * (*devProc)(), which should be of the following form:
+ *   see also typedef cb_extflat_hiervisitdevs_t:
  *
- *	(*devProc)(hc, dev, scale, cdata)
- *	    HierContext *hc;
- *	    Dev *dev;
- *	    float scale;
- *	    ClientData cdata;
+ *	int (*devProc)(
+ *	    HierContext *hc,
+ *	    Dev *dev,
+ *	    float scale,
+ *	    ClientData cdata)
  *	{
  *	}
  *
@@ -442,14 +443,14 @@ efHierDevKilled(hc, dev, prefix)
  */
 
 int
-EFHierVisitDevs(hc, devProc, cdata)
-    HierContext *hc;
-    int (*devProc)();
-    ClientData cdata;
+EFHierVisitDevs(
+    HierContext *hc,
+    const cb_extflat_hiervisitdevs_t devProc,
+    ClientData cdata)
 {
     CallArg ca;
 
-    ca.ca_proc = devProc;
+    ca.ca_proc = (int (*)()) devProc;
     ca.ca_cdata = cdata;
     return efHierVisitDevs(hc, (ClientData) &ca);
 }
@@ -492,7 +493,8 @@ efHierVisitDevs(hc, ca)
 	if (efHierDevKilled(hc, dev, hc->hc_hierName))
 	    continue;
 
-	if ((*ca->ca_proc)(hc, dev, scale, ca->ca_cdata))
+	const cb_extflat_hiervisitdevs_t ca_hiervisitdevs_proc = (cb_extflat_hiervisitdevs_t) ca->ca_proc; /* FIXME temporary */
+	if ((*ca_hiervisitdevs_proc)(hc, dev, scale, ca->ca_cdata)) /* @invoke cb_extflat_hiervisitdevs_t */
 	    return 1;
     }
     return 0;
@@ -518,25 +520,27 @@ efHierVisitDevs(hc, ca)
  */
 
 int
-efHierVisitSingleResist(hc, name1, name2, res, ca)
-    HierContext *hc;		/* Contains hierarchical pathname to cell */
-    char *name1, *name2;	/* Names of nodes connecting to resistor */
-    Connection *res;		/* Contains resistance to add */
-    CallArg *ca;
+efHierVisitSingleResist(
+    HierContext *hc,		/* Contains hierarchical pathname to cell */
+    const char *name1,
+    const char *name2,		/* Names of nodes connecting to resistor */
+    Connection *res,		/* Contains resistance to add */
+    ClientData cdata)		/* (CallArg *) */
 {
-    EFNode *n1, *n2;
+    CallArg *ca = (CallArg *) CD2PTR(cdata);
+    const EFNode *n1, *n2;
     HashEntry *he;
     Def *def = hc->hc_use->use_def;
 
     if ((he = HashLookOnly(&def->def_nodes, name1)) == NULL)
 	return 0;
-    n1 = ((EFNodeName *) HashGetValue(he))->efnn_node;
+    n1 = ((const EFNodeName *) HashGetValue(he))->efnn_node;
     if (n1->efnode_flags & EF_KILLED)
 	return 0;
 
     if ((he = HashLookOnly(&def->def_nodes, name2)) == NULL)
 	return 0;
-    n2 = ((EFNodeName *) HashGetValue(he))->efnn_node;
+    n2 = ((const EFNodeName *) HashGetValue(he))->efnn_node;
     if (n2->efnode_flags & EF_KILLED)
 	return 0;
 
@@ -544,7 +548,8 @@ efHierVisitSingleResist(hc, name1, name2, res, ca)
     if (n1 == n2)
 	return 0;
 
-    return (*ca->ca_proc)(hc, n1->efnode_name->efnn_hier,
+    const cb_extflat_hiervisitresists_t ca_hiervisitresists_proc = (cb_extflat_hiervisitresists_t) ca->ca_proc; /* FIXME temporary */
+    return (*ca_hiervisitresists_proc)(hc, n1->efnode_name->efnn_hier,
 		n2->efnode_name->efnn_hier,
 		res->conn_res, ca->ca_cdata);
 }
@@ -557,13 +562,15 @@ efHierVisitSingleResist(hc, name1, name2, res, ca)
  * Visit all the resistors in the circuit.
  * For each resistor in the circuit, call the user-supplied procedure
  * (*resProc)(), which should be of the following form, where hn1 and
- * hn2 are the HierNames of the two nodes connected by the resistor.
+ * hn2 are the HierNames of the two nodes connected by the resistor
+ *   see also typedef cb_extflat_hiervisitresists_t:
  *
- *	(*resProc)(hc, hn1, hn2, resistance, cdata)
- *	    HierContext *hc;
- *	    HierName *hn1, *hn2;
- *	    int resistance;
- *	    ClientData cdata;
+ *	int (*resProc)(
+ *	    HierContext *hc,
+ *	    const HierName *hierName1,
+ *	    const HierName *hierName2,
+ *	    float resistance,
+ *	    ClientData cdata)
  *	{
  *	}
  *
@@ -584,17 +591,17 @@ efHierVisitSingleResist(hc, name1, name2, res, ca)
  */
 
 int
-EFHierVisitResists(hc, resProc, cdata)
-    HierContext *hc;
-    int (*resProc)();
-    ClientData cdata;
+EFHierVisitResists(
+    HierContext *hc,
+    const cb_extflat_hiervisitresists_t resProc,
+    ClientData cdata)
 {
     CallArg ca;
-    int efHierVisitResists();	/* Forward reference */
+    int efHierVisitResists(HierContext *hc, CallArg *ca);	/* Forward reference */
 
-    ca.ca_proc = resProc;
+    ca.ca_proc = (int (*)()) resProc;
     ca.ca_cdata = cdata;
-    return efHierVisitResists(hc, (ClientData) &ca);
+    return efHierVisitResists(hc, &ca);
 }
 
 /*
@@ -609,9 +616,9 @@ EFHierVisitResists(hc, resProc, cdata)
  */
 
 int
-efHierVisitResists(hc, ca)
-    HierContext *hc;
-    CallArg *ca;
+efHierVisitResists(
+    HierContext *hc,
+    CallArg *ca)
 {
     Def *def = hc->hc_use->use_def;
     Connection *res;
@@ -628,7 +635,7 @@ efHierVisitResists(hc, ca)
 			res, ca))
 		return 1;
 	}
-	else if (efHierSrArray(hc, res, efHierVisitSingleResist, (ClientData) ca))
+	else if (efHierSrArray(hc, res, efHierVisitSingleResist, PTR2CD(ca)))
 	    return 1;
     }
     return 0;
