@@ -8,6 +8,9 @@
  * the X .h files.
  */
 
+#ifndef _MAGIC__GRAPHICS__GROGLINT_H
+#define _MAGIC__GRAPHICS__GROGLINT_H
+
 #include "utils/magic.h"
 
 /* Constants
@@ -52,16 +55,18 @@ typedef struct {
 extern OGL_CURRENT oglCurrent;
 
 extern bool groglGetCursorPos();
+extern bool groglGetCursorRootPos();
 extern bool groglDrawGrid();
 extern void GrOGLEnableTablet();
 extern void GrOGLDisableTablet();
 extern void GrOGLSetCMap();
 extern void GrOGLInitWithArgs();
 extern void groglPutText();
+extern void groglFontText();
 extern void groglDefineCursor();
 extern void GrOGLSetCursor();
 extern void GrOGLSetWindow();
-extern void GrOGLTextSize();
+extern int  GrOGLTextSize();
 extern void GrOGLDrawGlyph();
 extern void GrOGLBitBlt();
 extern void NullBitBlt();
@@ -71,9 +76,13 @@ extern void groglSetLineStyle();
 extern void groglSetCharSize();
 extern void groglSetWMandC();
 extern void groglFillRect();
-#ifdef NONMANHATTAN
 extern void groglFillPolygon();
-#endif
+
+extern void groglFreeBackingStore();
+extern void groglCreateBackingStore();
+extern bool groglGetBackingStore();
+extern bool groglScrollBackingStore();
+extern void groglPutBackingStore();
 
 extern Rect groglLines[];
 extern OGLRect groglRects[];
@@ -87,3 +96,5 @@ extern int groglNbRects;
 #define GR_X_FLUSH_LINES() {if (groglNbLines>0) {groglDrawLines(groglLines, groglNbLines); groglNbLines=0;}}
 #define GR_X_FLUSH_RECTS() {if (groglNbRects>0) {groglFillRects(groglRects, groglNbRects); groglNbRects=0;}}
 #define	GR_X_FLUSH_BATCH() {GR_X_FLUSH_LINES(); GR_X_FLUSH_RECTS();}
+
+#endif /* _MAGIC__GRAPHICS__GROGLINT_H */
