@@ -15,12 +15,13 @@ proc magic::suspendall {} {
    global Winopts
    if {[info commands winfo] != ""} {
       foreach window [magic::windownames layout] {
+	 if {$window == 0} {continue}
          set framename [winfo toplevel $window]
          if {$framename == "."} {
 	    set framename $window
          }
          if {[incr Winopts(${framename},suspend)] == 1} {
-	    $window update suspend
+	    $window updatedisplay suspend
          }
       }
    }
@@ -30,6 +31,7 @@ proc magic::resumeall {} {
    global Winopts
    if {[info commands winfo] != ""} {
       foreach window [magic::windownames layout] {
+	 if {$window == 0} {continue}
          set framename [winfo toplevel $window]
          if {$framename == "."} {
 	    set framename $window
@@ -40,7 +42,7 @@ proc magic::resumeall {} {
 	    incr Winopts($framename,suspend) -1
 	    if { $Winopts(${framename},suspend) <= 0 } {
 	       unset Winopts(${framename},suspend)
-	       $window update resume
+	       $window updatedisplay resume
 	    }
 	 }
       }
@@ -56,11 +58,31 @@ proc magic::makecrashbackup {} {
    global Opts
 
    *bypass crash save
-   if {$Opts(backupinterval) > 0} {
-      after $Opts(backupinterval) magic::makecrashbackup
+   if {![catch set Opts(backupinterval)]} {
+      if {$Opts(backupinterval) > 0} {
+         after $Opts(backupinterval) magic::makecrashbackup
+      }
    }
 }
 
+#----------------------------------------------------------------
+# magic::crashbackups ---
+#
+# Create periodic backups.  Options are:
+#
+#   start:	Begin periodic backups.  If interval is not
+#		specified, then set interval to 10 minutes.
+#
+#   resume:	Resume periodic backups if started and stopped,
+#		but not if disabled or never started.
+#
+#   stop:	Stop periodic backups.
+#
+#   disable:	Disable periodic backups;  set to state of
+#		never having been started.
+#
+#----------------------------------------------------------------
+
 proc magic::crashbackups {{option start}} {
    global Opts
 
@@ -69,12 +91,25 @@ proc magic::crashbackups {{option start}} {
          if {[catch set Opts(backupinterval)]} {
             set Opts(backupinterval) 600000
          }
-         after $Opts(backupinterval) magic::makecrashbackup
+	 if {$Opts(backupinterval) > 0} {
+	    after $Opts(backupinterval) magic::makecrashbackup
+	 }
+      }
+      resume {
+         if {![catch set Opts(backupinterval)]} {
+	    if {$Opts(backupinterval) > 0} {
+	       after $Opts(backupinterval) magic::makecrashbackup
+	    }
+	 }
       }
       stop -
       cancel {
          after cancel magic::makecrashbackup
       }
+      disable {
+         after cancel magic::makecrashbackup
+	 unset Opts(backupinterval)
+      }
    }
 }
 
@@ -121,12 +156,17 @@ proc magic::popstack {} {
    } else {
       set ltag [tag load]
       tag load {}
+      suspendall
       load [lindex $editstack end]
+      set snaptype [snap]
+      snap internal
       view [lindex $editstack end-1]
-      tag load $ltag
-      set editstack [lrange $editstack 0 end-2]
+      snap $snaptype
       catch {magic::cellmanager}
       catch {magic::captions}
+      resumeall
+      tag load $ltag
+      set editstack [lrange $editstack 0 end-2]
    }
    return
 }
@@ -315,6 +355,9 @@ proc magic::ruler {{text {}} {orient auto}} {
    set mmx [expr {($llx + $urx) / 2}]
    set mmy [expr {($lly + $ury) / 2}]
 
+   set snapsave [snap]
+   snap internal
+
    if {$orient == "horizontal"} {
       element add line l1_$Opts(rulers) black $llx $lly $llx $ury
       element add line l4_$Opts(rulers) black $urx $lly $urx $ury
@@ -367,6 +410,7 @@ proc magic::ruler {{text {}} {orient auto}} {
 	  element configure l3_$Opts(rulers) flags arrowbottom
       }
    }
+   snap $snapsave
 }
 
 #---------------------------------------------------------------------
@@ -472,8 +516,55 @@ proc magic::enable_tools {} {
    magic::macro space		{magic::tool}
    magic::macro Shift_space	{magic::tool box}
 
+   # Set these first because the magic::tool command defined
+   # in this script depends on them being valid.
    set Opts(tool) box
    set Opts(motion) {}
+
+   # Set up unique key macros for each individual tool.  This
+   # effectively defines what the tools are, since each tool
+   # is really just a collection of unique key bindings.  The
+   # default bindings are copied from the "box" tool, and
+   # then replacement bindings for button actions are applied.
+   # The user can change these bindings at will by using the
+   # "macro" command when the tool is active.
+
+   magic::macro copy wiring
+   magic::macro copy netlist
+   magic::macro copy pick
+
+   magic::tool wiring
+   macro  Button1          "magic::trackwire %W pick"
+   macro  Button2          "magic::trackwire %W done"
+   macro  Button3          "magic::trackwire %W cancel"
+   macro  Shift_Button1    "wire incr type ; wire show"
+   macro  Shift_Button2    "wire switch"
+   macro  Shift_Button3    "wire decr type ; wire show"
+   macro  Button4 "wire incr width ; wire show"
+   macro  Button5 "wire decr width ; wire show"
+
+   magic::tool netlist
+   macro  Button1          "netlist select"
+   macro  Button2          "netlist join"
+   macro  Button3          "netlist terminal"
+   # Remove shift-button bindings
+   macro  Shift_Button1    ""
+   macro  Shift_Button2    ""
+   macro  Shift_Button3    ""
+   macro  Button4 "scroll u .05 w"
+   macro  Button5 "scroll d .05 w"
+
+   magic::tool pick
+   macro  Button1          "magic::keepselect %W"
+   macro  Shift_Button2    "magic::startselect %W copy"
+   macro  Button2          "magic::startselect %W pick"
+   macro  Button3          "magic::cancelselect %W"
+   macro  Shift_Button1    "box corner bl cursor"
+   macro  Shift_Button3    "box move ur cursor"
+   macro  Button4 "scroll u .05 w"
+   macro  Button5 "scroll d .05 w"
+
+   magic::tool box
    set Opts(origin) {0 0}
    set Opts(backupinterval) 60000
    magic::crashbackups start
@@ -600,6 +691,9 @@ proc magic::tool {{type next}} {
       }
    }
    switch $type {
+      type {
+	 return $Opts(tool)
+      }
       info {
 	 # print information about the current tool.
 	 puts stdout "Current tool is $Opts(tool)."
@@ -631,63 +725,32 @@ proc magic::tool {{type next}} {
 	 if {[llength [macro Control_Button3]] > 0} {
 	    macro Control_Button3
 	 }
+	 if {[llength [macro Button4]] > 0} {
+	    macro Button4
+	 }
+	 if {[llength [macro Button5]] > 0} {
+	    macro Button5
+	 }
       }
       box {
 	 puts stdout {Switching to BOX tool.}
 	 set Opts(tool) box
 	 cursor 0	;# sets the cursor
-	 macro  Button1          "box move bl cursor; magic::boxview %W %1"
-	 macro  Shift_Button1    "box corner bl cursor; magic::boxview %W %1"
-	 macro  Button2          "paint cursor"
-	 macro  Shift_Button2    "erase cursor"
-	 macro  Button3          "box corner ur cursor"
-	 macro  Shift_Button3    "box move ur cursor; magic::boxview %W %1"
-	 macro  Button4 "scroll u .05 w; magic::boxview %W %1"
-	 macro  Button5 "scroll d .05 w; magic::boxview %W %1"
-	 macro  Shift_XK_Pointer_Button4 "scroll r .05 w; magic::boxview %W %1"
-	 macro  Shift_XK_Pointer_Button5 "scroll l .05 w; magic::boxview %W %1"
-
       }
       wiring {
 	 puts stdout {Switching to WIRING tool.}
 	 set Opts(tool) wiring
 	 cursor 19 	;# sets the cursor
-	 macro  Button1          "magic::trackwire %W pick"
-	 macro  Button2          "magic::trackwire %W done"
-	 macro  Button3          "magic::trackwire %W cancel"
-         macro  Shift_Button1    "wire incr type ; wire show"
-	 macro  Shift_Button2    "wire switch"
-	 macro  Shift_Button3    "wire decr type ; wire show"
-	 macro  Button4 "wire incr width ; wire show"
-	 macro  Button5 "wire decr width ; wire show"
-
       }
       netlist {
 	 puts stdout {Switching to NETLIST tool.}
 	 set Opts(tool) netlist
 	 cursor 18	;# sets the cursor
-         macro  Button1          "netlist select"
-	 macro  Button2          "netlist join"
-	 macro  Button3          "netlist terminal"
-         # Remove shift-button bindings
-         macro  Shift_Button1    ""
-	 macro  Shift_Button2    ""
-	 macro  Shift_Button3    ""
-	 macro  Button4 "scroll u .05 w"
-	 macro  Button5 "scroll d .05 w"
       }
       pick {
 	 puts stdout {Switching to PICK tool.}
 	 set Opts(tool) pick
 	 cursor 22	;# set the cursor
-         macro  Button1          "magic::keepselect %W"
-	 macro  Shift_Button2    "magic::startselect %W copy"
-	 macro  Button2          "magic::startselect %W pick"
-	 macro  Button3          "magic::cancelselect %W"
-	 macro  Shift_Button1    "box corner bl cursor"
-	 macro  Shift_Button3    "box move ur cursor"
-	 macro  Button4 "scroll u .05 w"
-	 macro  Button5 "scroll d .05 w"
       }
    }
 
